"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_slo_createslorequest import (
    V3SLOCreateSLORequest,
    V3SLOCreateSLORequestTypedDict,
)
from .v3_slo_slodetailedresponse import (
    V3SLOSLODetailedResponse,
    V3SLOSLODetailedResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import (
    FieldMetadata,
    PathParamMetadata,
    QueryParamMetadata,
    RequestMetadata,
)
from typing_extensions import Annotated, TypedDict


class SLOUpdateSLORequestTypedDict(TypedDict):
    slo_id: int
    owner_id_param: str
    v3_slo_create_slo_request: V3SLOCreateSLORequestTypedDict


class SLOUpdateSLORequest(BaseModel):
    slo_id: Annotated[
        int,
        pydantic.Field(alias="sloID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    owner_id_param: Annotated[
        str,
        pydantic.Field(alias="owner_id"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ]

    v3_slo_create_slo_request: Annotated[
        V3SLOCreateSLORequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class SLOUpdateSLODataTypedDict(TypedDict):
    slo: V3SLOSLODetailedResponseTypedDict


class SLOUpdateSLOData(BaseModel):
    slo: V3SLOSLODetailedResponse


class SLOUpdateSLOResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: SLOUpdateSLODataTypedDict


class SLOUpdateSLOResponse(BaseModel):
    r"""The request has succeeded."""

    data: SLOUpdateSLOData



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ServicesOverlayDedupKeyOverlayTypedDict(TypedDict):
    template: str
    duration: int


class V3ServicesOverlayDedupKeyOverlay(BaseModel):
    template: str

    duration: int



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_squads_squadresponse import (
    V3SquadsSquadResponse,
    V3SquadsSquadResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, QueryParamMetadata
from typing import List
from typing_extensions import Annotated, TypedDict


class SquadsGetSquadByTeamRequestTypedDict(TypedDict):
    owner_id: str


class SquadsGetSquadByTeamRequest(BaseModel):
    owner_id: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]


class SquadsGetSquadByTeamResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: List[V3SquadsSquadResponseTypedDict]


class SquadsGetSquadByTeamResponse(BaseModel):
    r"""The request has succeeded."""

    data: List[V3SquadsSquadResponse]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_exportformat import V3IncidentsExportFormat
from .v3_incidents_exportincidentsfilter import (
    V3IncidentsExportIncidentsFilter,
    V3IncidentsExportIncidentsFilterTypedDict,
)
from datetime import datetime
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsIncidentExportAsyncRequestTypedDict(TypedDict):
    r"""Request body for async incident export."""

    owner_id: str
    type: V3IncidentsExportFormat
    r"""Type of export, can be csv or json"""
    start_time: datetime
    end_time: datetime
    incident_filters: V3IncidentsExportIncidentsFilterTypedDict
    r"""Filter criteria for incidents in an export."""


class V3IncidentsIncidentExportAsyncRequest(BaseModel):
    r"""Request body for async incident export."""

    owner_id: str

    type: V3IncidentsExportFormat
    r"""Type of export, can be csv or json"""

    start_time: datetime

    end_time: datetime

    incident_filters: V3IncidentsExportIncidentsFilter
    r"""Filter criteria for incidents in an export."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .common_v3_entityowner import CommonV3EntityOwner, CommonV3EntityOwnerTypedDict
from .common_v3_rbacowner import CommonV3RBACOwner, CommonV3RBACOwnerTypedDict
from .v3_runbooks_step import V3RunbooksStep, V3RunbooksStepTypedDict
from .v3_runbooks_updationinfo import (
    V3RunbooksUpdationInfo,
    V3RunbooksUpdationInfoTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3RunbooksRunbookResponseTypedDict(TypedDict):
    r"""Represents a Runbook in the system."""

    id: str
    r"""The unique identifier for the runbook."""
    name: str
    r"""The name of the runbook."""
    created: V3RunbooksUpdationInfoTypedDict
    r"""Information about when the runbook was created."""
    updated: V3RunbooksUpdationInfoTypedDict
    r"""Information about when the runbook was last updated."""
    used_count: int
    r"""The number of times this runbook has been used."""
    steps: List[V3RunbooksStepTypedDict]
    r"""The steps that make up the runbook."""
    entity_owner: CommonV3EntityOwnerTypedDict
    r"""The owner of the entity."""
    organization_id: str
    r"""The ID of the organization this runbook belongs to."""
    owner: CommonV3RBACOwnerTypedDict
    r"""The RBAC owner of the runbook (typically a team)."""


class V3RunbooksRunbookResponse(BaseModel):
    r"""Represents a Runbook in the system."""

    id: str
    r"""The unique identifier for the runbook."""

    name: str
    r"""The name of the runbook."""

    created: V3RunbooksUpdationInfo
    r"""Information about when the runbook was created."""

    updated: V3RunbooksUpdationInfo
    r"""Information about when the runbook was last updated."""

    used_count: int
    r"""The number of times this runbook has been used."""

    steps: List[V3RunbooksStep]
    r"""The steps that make up the runbook."""

    entity_owner: CommonV3EntityOwner
    r"""The owner of the entity."""

    organization_id: str
    r"""The ID of the organization this runbook belongs to."""

    owner: CommonV3RBACOwner
    r"""The RBAC owner of the runbook (typically a team)."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_teams_teamroleresponse import (
    V3TeamsTeamRoleResponse,
    V3TeamsTeamRoleResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing import List
from typing_extensions import Annotated, TypedDict


class TeamsGetAllTeamRolesRequestTypedDict(TypedDict):
    team_id: str


class TeamsGetAllTeamRolesRequest(BaseModel):
    team_id: Annotated[
        str,
        pydantic.Field(alias="teamId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class TeamsGetAllTeamRolesResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: List[V3TeamsTeamRoleResponseTypedDict]


class TeamsGetAllTeamRolesResponse(BaseModel):
    r"""The request has succeeded."""

    data: List[V3TeamsTeamRoleResponse]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsSnoozeNotificationsSnoozeIncidentResponseTypedDict(TypedDict):
    incident_id: str
    is_snoozed: bool
    snooze_end_time: str


class V3IncidentsSnoozeNotificationsSnoozeIncidentResponse(BaseModel):
    incident_id: str

    is_snoozed: bool

    snooze_end_time: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List, Literal
from typing_extensions import TypedDict


StatusEnum = Literal[
    "queued",
    "running",
    "successful",
    "partial",
    "failed",
]


class V3WorkflowsGetWorkflowLogsResponseDataTypedDict(TypedDict):
    id: str
    status: StatusEnum
    incident_id: str
    action_execution: str
    message: str
    executed_at: str


class V3WorkflowsGetWorkflowLogsResponseData(BaseModel):
    id: str

    status: StatusEnum

    incident_id: str

    action_execution: str

    message: str

    executed_at: str


class V3WorkflowsGetWorkflowLogsResponseMetaTypedDict(TypedDict):
    total_count: int


class V3WorkflowsGetWorkflowLogsResponseMeta(BaseModel):
    total_count: int


class V3WorkflowsGetWorkflowLogsResponseTypedDict(TypedDict):
    data: List[V3WorkflowsGetWorkflowLogsResponseDataTypedDict]
    meta: V3WorkflowsGetWorkflowLogsResponseMetaTypedDict


class V3WorkflowsGetWorkflowLogsResponse(BaseModel):
    data: List[V3WorkflowsGetWorkflowLogsResponseData]

    meta: V3WorkflowsGetWorkflowLogsResponseMeta



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_slo_sloviolatingincidentresponse import (
    V3SLOSLOViolatingIncidentResponse,
    V3SLOSLOViolatingIncidentResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import (
    FieldMetadata,
    PathParamMetadata,
    QueryParamMetadata,
    RequestMetadata,
)
from typing_extensions import Annotated, TypedDict


class SLOMarkSLOFalsePositiveRequestBodyTypedDict(TypedDict):
    pass


class SLOMarkSLOFalsePositiveRequestBody(BaseModel):
    pass


class SLOMarkSLOFalsePositiveRequestTypedDict(TypedDict):
    slo_id: int
    incident_id: int
    value: bool
    owner_id: str
    request_body: SLOMarkSLOFalsePositiveRequestBodyTypedDict


class SLOMarkSLOFalsePositiveRequest(BaseModel):
    slo_id: Annotated[
        int,
        pydantic.Field(alias="sloID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    incident_id: Annotated[
        int,
        pydantic.Field(alias="incidentID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    value: Annotated[
        bool, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    owner_id: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=False))
    ]

    request_body: Annotated[
        SLOMarkSLOFalsePositiveRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class SLOMarkSLOFalsePositiveDataTypedDict(TypedDict):
    slo_violating_incident: V3SLOSLOViolatingIncidentResponseTypedDict


class SLOMarkSLOFalsePositiveData(BaseModel):
    slo_violating_incident: V3SLOSLOViolatingIncidentResponse


class SLOMarkSLOFalsePositiveResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: SLOMarkSLOFalsePositiveDataTypedDict


class SLOMarkSLOFalsePositiveResponse(BaseModel):
    r"""The request has succeeded."""

    data: SLOMarkSLOFalsePositiveData



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_workflows_componentandimpact import (
    V3WorkflowsComponentAndImpact,
    V3WorkflowsComponentAndImpactTypedDict,
)
from .v3_workflows_issuestatusandmessage import (
    V3WorkflowsIssueStatusAndMessage,
    V3WorkflowsIssueStatusAndMessageTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List, Literal, Optional
from typing_extensions import NotRequired, TypedDict


V3WorkflowsSqCreateStatusPageIssueUpdateName = Literal["sq_add_status_page_issue",]


class V3WorkflowsSqCreateStatusPageIssueUpdateDataTypedDict(TypedDict):
    component_and_impact: NotRequired[List[V3WorkflowsComponentAndImpactTypedDict]]
    issue_title: NotRequired[str]
    page_status_id: NotRequired[int]
    status_and_message: NotRequired[List[V3WorkflowsIssueStatusAndMessageTypedDict]]
    status_page_id: NotRequired[int]


class V3WorkflowsSqCreateStatusPageIssueUpdateData(BaseModel):
    component_and_impact: Optional[List[V3WorkflowsComponentAndImpact]] = None

    issue_title: Optional[str] = None

    page_status_id: Optional[int] = None

    status_and_message: Optional[List[V3WorkflowsIssueStatusAndMessage]] = None

    status_page_id: Optional[int] = None


class V3WorkflowsSqCreateStatusPageIssueUpdateTypedDict(TypedDict):
    name: V3WorkflowsSqCreateStatusPageIssueUpdateName
    data: NotRequired[V3WorkflowsSqCreateStatusPageIssueUpdateDataTypedDict]


class V3WorkflowsSqCreateStatusPageIssueUpdate(BaseModel):
    name: V3WorkflowsSqCreateStatusPageIssueUpdateName

    data: Optional[V3WorkflowsSqCreateStatusPageIssueUpdateData] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_globaloncallreminderrules_globaloncallreminderruleresponse import (
    V3GlobalOncallReminderRulesGlobalOncallReminderRuleResponse,
    V3GlobalOncallReminderRulesGlobalOncallReminderRuleResponseTypedDict,
)
from .v3_globaloncallreminderrules_updateglobaloncallreminderrulesrequest import (
    V3GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesRequest,
    V3GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesRequestTypedDict,
)
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, QueryParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesRequestTypedDict(
    TypedDict
):
    owner_id: str
    v3_global_oncall_reminder_rules_update_global_oncall_reminder_rules_request: (
        V3GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesRequestTypedDict
    )


class GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesRequest(BaseModel):
    owner_id: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]

    v3_global_oncall_reminder_rules_update_global_oncall_reminder_rules_request: (
        Annotated[
            V3GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesRequest,
            FieldMetadata(request=RequestMetadata(media_type="application/json")),
        ]
    )


class GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesResponseTypedDict(
    TypedDict
):
    r"""The request has succeeded."""

    data: V3GlobalOncallReminderRulesGlobalOncallReminderRuleResponseTypedDict


class GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3GlobalOncallReminderRulesGlobalOncallReminderRuleResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3WebformsWFServiceTypedDict(TypedDict):
    r"""Service details for a webform"""

    service_id: str
    r"""Public identifier for the service"""
    name: str
    r"""Service name as shown in UI"""
    alias: str
    r"""Optional alias for the service"""


class V3WebformsWFService(BaseModel):
    r"""Service details for a webform"""

    service_id: str
    r"""Public identifier for the service"""

    name: str
    r"""Service name as shown in UI"""

    alias: str
    r"""Optional alias for the service"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_teams_addbulkteammemberrequest import (
    V3TeamsAddBulkTeamMemberRequest,
    V3TeamsAddBulkTeamMemberRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TeamsAddBulkTeamMemberRequestTypedDict(TypedDict):
    team_id: str
    v3_teams_add_bulk_team_member_request: V3TeamsAddBulkTeamMemberRequestTypedDict


class TeamsAddBulkTeamMemberRequest(BaseModel):
    team_id: Annotated[
        str,
        pydantic.Field(alias="teamId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_teams_add_bulk_team_member_request: Annotated[
        V3TeamsAddBulkTeamMemberRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class TeamsAddBulkTeamMemberMemberTypedDict(TypedDict):
    user_id: NotRequired[str]
    role_ids: NotRequired[List[str]]


class TeamsAddBulkTeamMemberMember(BaseModel):
    user_id: Optional[str] = None

    role_ids: Optional[List[str]] = None


class TeamsAddBulkTeamMemberDataTypedDict(TypedDict):
    team_id: str
    members: List[TeamsAddBulkTeamMemberMemberTypedDict]


class TeamsAddBulkTeamMemberData(BaseModel):
    team_id: str

    members: List[TeamsAddBulkTeamMemberMember]


class TeamsAddBulkTeamMemberResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: TeamsAddBulkTeamMemberDataTypedDict


class TeamsAddBulkTeamMemberResponse(BaseModel):
    r"""The request has succeeded."""

    data: TeamsAddBulkTeamMemberData



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_squads_squadresponse import (
    V4SquadsSquadResponse,
    V4SquadsSquadResponseTypedDict,
)
from .v4_squads_updatesquadrequest import (
    V4SquadsUpdateSquadRequest,
    V4SquadsUpdateSquadRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class SquadsUpdateSquadV4RequestTypedDict(TypedDict):
    squad_id: str
    v4_squads_update_squad_request: V4SquadsUpdateSquadRequestTypedDict


class SquadsUpdateSquadV4Request(BaseModel):
    squad_id: Annotated[
        str,
        pydantic.Field(alias="squadID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v4_squads_update_squad_request: Annotated[
        V4SquadsUpdateSquadRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class SquadsUpdateSquadV4ResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4SquadsSquadResponseTypedDict


class SquadsUpdateSquadV4Response(BaseModel):
    r"""The request has succeeded."""

    data: V4SquadsSquadResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from squadcast_sdk import errors, models, utils
from squadcast_sdk._hooks import HookContext
from squadcast_sdk.types import OptionalNullable, UNSET
from squadcast_sdk.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, List, Mapping, Optional, Union


class Webhooks(BaseSDK):
    def create(
        self,
        *,
        name: str,
        triggers: Union[
            List[models.V3ExtensionsWebhooksWebhookTrigger],
            List[models.V3ExtensionsWebhooksWebhookTriggerTypedDict],
        ],
        urls: Union[
            List[models.V3ExtensionsWebhooksWebhookURL],
            List[models.V3ExtensionsWebhooksWebhookURLTypedDict],
        ],
        trigger_type: str,
        description: Optional[str] = None,
        header: OptionalNullable[
            Union[
                models.V3ExtensionsWebhooksWebhookHeader,
                models.V3ExtensionsWebhooksWebhookHeaderTypedDict,
            ]
        ] = UNSET,
        filters: OptionalNullable[
            Union[
                models.V3ExtensionsWebhooksWebhookFilter,
                models.V3ExtensionsWebhooksWebhookFilterTypedDict,
            ]
        ] = UNSET,
        max_retry: Optional[int] = None,
        teams: OptionalNullable[List[str]] = UNSET,
        is_all_teams_configured: Optional[bool] = None,
        custom_payload_template_slug: Optional[str] = None,
        language: Optional[str] = None,
        mail_ids: OptionalNullable[List[str]] = UNSET,
        custom_payload: Optional[str] = None,
        payload_type: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.WebhooksCreateWebhookResponse:
        r"""Create Webhook

        Add webhook to the organization. Returns the webhook object in response.
        Requires `access_token` as a `Bearer {{token}}` in the `Authorization` header with `user-write` scope.

        :param name: Name of the webhook
        :param triggers: A list of triggers for this webhook
        :param urls: A list of URLs to which the webhook payload will be sent
        :param trigger_type: Type of trigger
        :param description: Description of the webhook
        :param header: Headers to be sent with the webhook
        :param filters: Filters to apply to the webhook
        :param max_retry: Maximum number of retries for the webhook
        :param teams: List of team IDs to which this webhook is applicable
        :param is_all_teams_configured: Set to true if the webhook is configured for all teams
        :param custom_payload_template_slug: Slug of the custom payload template
        :param language: Language for the webhook payload
        :param mail_ids: List of email IDs for notification
        :param custom_payload: Custom payload for the webhook
        :param payload_type: Type of payload
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.V3ExtensionsWebhooksWebhook(
            name=name,
            description=description,
            triggers=utils.get_pydantic_model(
                triggers, List[models.V3ExtensionsWebhooksWebhookTrigger]
            ),
            urls=utils.get_pydantic_model(
                urls, List[models.V3ExtensionsWebhooksWebhookURL]
            ),
            header=utils.get_pydantic_model(
                header, OptionalNullable[models.V3ExtensionsWebhooksWebhookHeader]
            ),
            filters=utils.get_pydantic_model(
                filters, OptionalNullable[models.V3ExtensionsWebhooksWebhookFilter]
            ),
            max_retry=max_retry,
            teams=teams,
            is_all_teams_configured=is_all_teams_configured,
            custom_payload_template_slug=custom_payload_template_slug,
            language=language,
            mail_ids=mail_ids,
            trigger_type=trigger_type,
            custom_payload=custom_payload,
            payload_type=payload_type,
        )

        req = self._build_request(
            method="POST",
            path="/v3/extensions/event-webhooks",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.V3ExtensionsWebhooksWebhook
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="Webhooks_createWebhook",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "402",
                "403",
                "404",
                "409",
                "422",
                "4XX",
                "500",
                "502",
                "503",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "201", "application/json"):
            return unmarshal_json_response(
                models.WebhooksCreateWebhookResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthorizedErrorData, http_res
            )
            raise errors.UnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "402", "application/json"):
            response_data = unmarshal_json_response(
                errors.PaymentRequiredErrorData, http_res
            )
            raise errors.PaymentRequiredError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(errors.ForbiddenErrorData, http_res)
            raise errors.ForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(errors.NotFoundErrorData, http_res)
            raise errors.NotFoundError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(errors.ConflictErrorData, http_res)
            raise errors.ConflictError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res
            )
            raise errors.UnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "502", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadGatewayErrorData, http_res
            )
            raise errors.BadGatewayError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "504", "application/json"):
            response_data = unmarshal_json_response(
                errors.GatewayTimeoutErrorData, http_res
            )
            raise errors.GatewayTimeoutError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)

        raise errors.SDKDefaultError("Unexpected response received", http_res)

    async def create_async(
        self,
        *,
        name: str,
        triggers: Union[
            List[models.V3ExtensionsWebhooksWebhookTrigger],
            List[models.V3ExtensionsWebhooksWebhookTriggerTypedDict],
        ],
        urls: Union[
            List[models.V3ExtensionsWebhooksWebhookURL],
            List[models.V3ExtensionsWebhooksWebhookURLTypedDict],
        ],
        trigger_type: str,
        description: Optional[str] = None,
        header: OptionalNullable[
            Union[
                models.V3ExtensionsWebhooksWebhookHeader,
                models.V3ExtensionsWebhooksWebhookHeaderTypedDict,
            ]
        ] = UNSET,
        filters: OptionalNullable[
            Union[
                models.V3ExtensionsWebhooksWebhookFilter,
                models.V3ExtensionsWebhooksWebhookFilterTypedDict,
            ]
        ] = UNSET,
        max_retry: Optional[int] = None,
        teams: OptionalNullable[List[str]] = UNSET,
        is_all_teams_configured: Optional[bool] = None,
        custom_payload_template_slug: Optional[str] = None,
        language: Optional[str] = None,
        mail_ids: OptionalNullable[List[str]] = UNSET,
        custom_payload: Optional[str] = None,
        payload_type: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.WebhooksCreateWebhookResponse:
        r"""Create Webhook

        Add webhook to the organization. Returns the webhook object in response.
        Requires `access_token` as a `Bearer {{token}}` in the `Authorization` header with `user-write` scope.

        :param name: Name of the webhook
        :param triggers: A list of triggers for this webhook
        :param urls: A list of URLs to which the webhook payload will be sent
        :param trigger_type: Type of trigger
        :param description: Description of the webhook
        :param header: Headers to be sent with the webhook
        :param filters: Filters to apply to the webhook
        :param max_retry: Maximum number of retries for the webhook
        :param teams: List of team IDs to which this webhook is applicable
        :param is_all_teams_configured: Set to true if the webhook is configured for all teams
        :param custom_payload_template_slug: Slug of the custom payload template
        :param language: Language for the webhook payload
        :param mail_ids: List of email IDs for notification
        :param custom_payload: Custom payload for the webhook
        :param payload_type: Type of payload
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.V3ExtensionsWebhooksWebhook(
            name=name,
            description=description,
            triggers=utils.get_pydantic_model(
                triggers, List[models.V3ExtensionsWebhooksWebhookTrigger]
            ),
            urls=utils.get_pydantic_model(
                urls, List[models.V3ExtensionsWebhooksWebhookURL]
            ),
            header=utils.get_pydantic_model(
                header, OptionalNullable[models.V3ExtensionsWebhooksWebhookHeader]
            ),
            filters=utils.get_pydantic_model(
                filters, OptionalNullable[models.V3ExtensionsWebhooksWebhookFilter]
            ),
            max_retry=max_retry,
            teams=teams,
            is_all_teams_configured=is_all_teams_configured,
            custom_payload_template_slug=custom_payload_template_slug,
            language=language,
            mail_ids=mail_ids,
            trigger_type=trigger_type,
            custom_payload=custom_payload,
            payload_type=payload_type,
        )

        req = self._build_request_async(
            method="POST",
            path="/v3/extensions/event-webhooks",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.V3ExtensionsWebhooksWebhook
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="Webhooks_createWebhook",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "402",
                "403",
                "404",
                "409",
                "422",
                "4XX",
                "500",
                "502",
                "503",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "201", "application/json"):
            return unmarshal_json_response(
                models.WebhooksCreateWebhookResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthorizedErrorData, http_res
            )
            raise errors.UnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "402", "application/json"):
            response_data = unmarshal_json_response(
                errors.PaymentRequiredErrorData, http_res
            )
            raise errors.PaymentRequiredError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(errors.ForbiddenErrorData, http_res)
            raise errors.ForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(errors.NotFoundErrorData, http_res)
            raise errors.NotFoundError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(errors.ConflictErrorData, http_res)
            raise errors.ConflictError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res
            )
            raise errors.UnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "502", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadGatewayErrorData, http_res
            )
            raise errors.BadGatewayError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "504", "application/json"):
            response_data = unmarshal_json_response(
                errors.GatewayTimeoutErrorData, http_res
            )
            raise errors.GatewayTimeoutError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)

        raise errors.SDKDefaultError("Unexpected response received", http_res)

    def delete(
        self,
        *,
        event_webhook_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> bytes:
        r"""Delete Webhook

        Remove webhook from the organization. Upon success, the webhook will be removed from the organization.
        Requires `access_token` as a `Bearer {{token}}` in the `Authorization` header with `user-write` scope.

        :param event_webhook_id: (Required) event webhook ID
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.WebhooksDeleteWebhookRequest(
            event_webhook_id=event_webhook_id,
        )

        req = self._build_request(
            method="DELETE",
            path="/v3/extensions/event-webhooks/{eventWebhookID}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="*/*",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="Webhooks_deleteWebhook",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "402",
                "403",
                "404",
                "409",
                "422",
                "4XX",
                "500",
                "502",
                "503",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "204", "*/*"):
            http_res_bytes = utils.stream_to_bytes(http_res)
            return http_res_bytes
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthorizedErrorData, http_res
            )
            raise errors.UnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "402", "application/json"):
            response_data = unmarshal_json_response(
                errors.PaymentRequiredErrorData, http_res
            )
            raise errors.PaymentRequiredError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(errors.ForbiddenErrorData, http_res)
            raise errors.ForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(errors.NotFoundErrorData, http_res)
            raise errors.NotFoundError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(errors.ConflictErrorData, http_res)
            raise errors.ConflictError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res
            )
            raise errors.UnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "502", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadGatewayErrorData, http_res
            )
            raise errors.BadGatewayError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "504", "application/json"):
            response_data = unmarshal_json_response(
                errors.GatewayTimeoutErrorData, http_res
            )
            raise errors.GatewayTimeoutError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)

        raise errors.SDKDefaultError("Unexpected response received", http_res)

    async def delete_async(
        self,
        *,
        event_webhook_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> bytes:
        r"""Delete Webhook

        Remove webhook from the organization. Upon success, the webhook will be removed from the organization.
        Requires `access_token` as a `Bearer {{token}}` in the `Authorization` header with `user-write` scope.

        :param event_webhook_id: (Required) event webhook ID
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.WebhooksDeleteWebhookRequest(
            event_webhook_id=event_webhook_id,
        )

        req = self._build_request_async(
            method="DELETE",
            path="/v3/extensions/event-webhooks/{eventWebhookID}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="*/*",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="Webhooks_deleteWebhook",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "402",
                "403",
                "404",
                "409",
                "422",
                "4XX",
                "500",
                "502",
                "503",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "204", "*/*"):
            http_res_bytes = await utils.stream_to_bytes_async(http_res)
            return http_res_bytes
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthorizedErrorData, http_res
            )
            raise errors.UnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "402", "application/json"):
            response_data = unmarshal_json_response(
                errors.PaymentRequiredErrorData, http_res
            )
            raise errors.PaymentRequiredError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(errors.ForbiddenErrorData, http_res)
            raise errors.ForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(errors.NotFoundErrorData, http_res)
            raise errors.NotFoundError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(errors.ConflictErrorData, http_res)
            raise errors.ConflictError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res
            )
            raise errors.UnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "502", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadGatewayErrorData, http_res
            )
            raise errors.BadGatewayError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "504", "application/json"):
            response_data = unmarshal_json_response(
                errors.GatewayTimeoutErrorData, http_res
            )
            raise errors.GatewayTimeoutError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)

        raise errors.SDKDefaultError("Unexpected response received", http_res)

    def get_by_id(
        self,
        *,
        event_webhook_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.V3ExtensionsWebhooksWebhookResponse:
        r"""Get Webhook By ID

        Returns a webhooks details of the given `eventWebhookID` in the request param.
        Requires `access_token` as a `Bearer {{token}}` in the `Authorization` header with `read` scope.

        :param event_webhook_id: (Required) event webhook ID
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.WebhooksGetWebhookByIDRequest(
            event_webhook_id=event_webhook_id,
        )

        req = self._build_request(
            method="GET",
            path="/v3/extensions/event-webhooks/{eventWebhookID}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="Webhooks_getWebhookById",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "402",
                "403",
                "404",
                "409",
                "422",
                "4XX",
                "500",
                "502",
                "503",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.WebhooksGetWebhookByIDResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthorizedErrorData, http_res
            )
            raise errors.UnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "402", "application/json"):
            response_data = unmarshal_json_response(
                errors.PaymentRequiredErrorData, http_res
            )
            raise errors.PaymentRequiredError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(errors.ForbiddenErrorData, http_res)
            raise errors.ForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(errors.NotFoundErrorData, http_res)
            raise errors.NotFoundError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(errors.ConflictErrorData, http_res)
            raise errors.ConflictError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res
            )
            raise errors.UnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "502", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadGatewayErrorData, http_res
            )
            raise errors.BadGatewayError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "504", "application/json"):
            response_data = unmarshal_json_response(
                errors.GatewayTimeoutErrorData, http_res
            )
            raise errors.GatewayTimeoutError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)

        raise errors.SDKDefaultError("Unexpected response received", http_res)

    async def get_by_id_async(
        self,
        *,
        event_webhook_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.V3ExtensionsWebhooksWebhookResponse:
        r"""Get Webhook By ID

        Returns a webhooks details of the given `eventWebhookID` in the request param.
        Requires `access_token` as a `Bearer {{token}}` in the `Authorization` header with `read` scope.

        :param event_webhook_id: (Required) event webhook ID
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.WebhooksGetWebhookByIDRequest(
            event_webhook_id=event_webhook_id,
        )

        req = self._build_request_async(
            method="GET",
            path="/v3/extensions/event-webhooks/{eventWebhookID}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="Webhooks_getWebhookById",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "402",
                "403",
                "404",
                "409",
                "422",
                "4XX",
                "500",
                "502",
                "503",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.WebhooksGetWebhookByIDResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthorizedErrorData, http_res
            )
            raise errors.UnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "402", "application/json"):
            response_data = unmarshal_json_response(
                errors.PaymentRequiredErrorData, http_res
            )
            raise errors.PaymentRequiredError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(errors.ForbiddenErrorData, http_res)
            raise errors.ForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(errors.NotFoundErrorData, http_res)
            raise errors.NotFoundError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(errors.ConflictErrorData, http_res)
            raise errors.ConflictError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res
            )
            raise errors.UnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "502", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadGatewayErrorData, http_res
            )
            raise errors.BadGatewayError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "504", "application/json"):
            response_data = unmarshal_json_response(
                errors.GatewayTimeoutErrorData, http_res
            )
            raise errors.GatewayTimeoutError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)

        raise errors.SDKDefaultError("Unexpected response received", http_res)

    def update(
        self,
        *,
        event_webhook_id: str,
        name: str,
        triggers: Union[
            List[models.V3ExtensionsWebhooksWebhookTrigger],
            List[models.V3ExtensionsWebhooksWebhookTriggerTypedDict],
        ],
        urls: Union[
            List[models.V3ExtensionsWebhooksWebhookURL],
            List[models.V3ExtensionsWebhooksWebhookURLTypedDict],
        ],
        trigger_type: str,
        description: Optional[str] = None,
        header: OptionalNullable[
            Union[
                models.V3ExtensionsWebhooksWebhookHeader,
                models.V3ExtensionsWebhooksWebhookHeaderTypedDict,
            ]
        ] = UNSET,
        filters: OptionalNullable[
            Union[
                models.V3ExtensionsWebhooksWebhookFilter,
                models.V3ExtensionsWebhooksWebhookFilterTypedDict,
            ]
        ] = UNSET,
        max_retry: Optional[int] = None,
        teams: OptionalNullable[List[str]] = UNSET,
        is_all_teams_configured: Optional[bool] = None,
        custom_payload_template_slug: Optional[str] = None,
        language: Optional[str] = None,
        mail_ids: OptionalNullable[List[str]] = UNSET,
        custom_payload: Optional[str] = None,
        payload_type: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.V3ExtensionsWebhooksWebhookResponse:
        r"""Update Webhook

        Update organization webhook details.
        Requires `access_token` as a `Bearer {{token}}` in the `Authorization` header with `user-write` scope.

        :param event_webhook_id:
        :param name: Name of the webhook
        :param triggers: A list of triggers for this webhook
        :param urls: A list of URLs to which the webhook payload will be sent
        :param trigger_type: Type of trigger
        :param description: Description of the webhook
        :param header: Headers to be sent with the webhook
        :param filters: Filters to apply to the webhook
        :param max_retry: Maximum number of retries for the webhook
        :param teams: List of team IDs to which this webhook is applicable
        :param is_all_teams_configured: Set to true if the webhook is configured for all teams
        :param custom_payload_template_slug: Slug of the custom payload template
        :param language: Language for the webhook payload
        :param mail_ids: List of email IDs for notification
        :param custom_payload: Custom payload for the webhook
        :param payload_type: Type of payload
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.WebhooksUpdateWebhookRequest(
            event_webhook_id=event_webhook_id,
            v3_extensions_webhooks_webhook=models.V3ExtensionsWebhooksWebhook(
                name=name,
                description=description,
                triggers=utils.get_pydantic_model(
                    triggers, List[models.V3ExtensionsWebhooksWebhookTrigger]
                ),
                urls=utils.get_pydantic_model(
                    urls, List[models.V3ExtensionsWebhooksWebhookURL]
                ),
                header=utils.get_pydantic_model(
                    header, OptionalNullable[models.V3ExtensionsWebhooksWebhookHeader]
                ),
                filters=utils.get_pydantic_model(
                    filters, OptionalNullable[models.V3ExtensionsWebhooksWebhookFilter]
                ),
                max_retry=max_retry,
                teams=teams,
                is_all_teams_configured=is_all_teams_configured,
                custom_payload_template_slug=custom_payload_template_slug,
                language=language,
                mail_ids=mail_ids,
                trigger_type=trigger_type,
                custom_payload=custom_payload,
                payload_type=payload_type,
            ),
        )

        req = self._build_request(
            method="PUT",
            path="/v3/extensions/event-webhooks/{eventWebhookID}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.v3_extensions_webhooks_webhook,
                False,
                False,
                "json",
                models.V3ExtensionsWebhooksWebhook,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="Webhooks_updateWebhook",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "402",
                "403",
                "404",
                "409",
                "422",
                "4XX",
                "500",
                "502",
                "503",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.WebhooksUpdateWebhookResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthorizedErrorData, http_res
            )
            raise errors.UnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "402", "application/json"):
            response_data = unmarshal_json_response(
                errors.PaymentRequiredErrorData, http_res
            )
            raise errors.PaymentRequiredError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(errors.ForbiddenErrorData, http_res)
            raise errors.ForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(errors.NotFoundErrorData, http_res)
            raise errors.NotFoundError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(errors.ConflictErrorData, http_res)
            raise errors.ConflictError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res
            )
            raise errors.UnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "502", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadGatewayErrorData, http_res
            )
            raise errors.BadGatewayError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "504", "application/json"):
            response_data = unmarshal_json_response(
                errors.GatewayTimeoutErrorData, http_res
            )
            raise errors.GatewayTimeoutError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)

        raise errors.SDKDefaultError("Unexpected response received", http_res)

    async def update_async(
        self,
        *,
        event_webhook_id: str,
        name: str,
        triggers: Union[
            List[models.V3ExtensionsWebhooksWebhookTrigger],
            List[models.V3ExtensionsWebhooksWebhookTriggerTypedDict],
        ],
        urls: Union[
            List[models.V3ExtensionsWebhooksWebhookURL],
            List[models.V3ExtensionsWebhooksWebhookURLTypedDict],
        ],
        trigger_type: str,
        description: Optional[str] = None,
        header: OptionalNullable[
            Union[
                models.V3ExtensionsWebhooksWebhookHeader,
                models.V3ExtensionsWebhooksWebhookHeaderTypedDict,
            ]
        ] = UNSET,
        filters: OptionalNullable[
            Union[
                models.V3ExtensionsWebhooksWebhookFilter,
                models.V3ExtensionsWebhooksWebhookFilterTypedDict,
            ]
        ] = UNSET,
        max_retry: Optional[int] = None,
        teams: OptionalNullable[List[str]] = UNSET,
        is_all_teams_configured: Optional[bool] = None,
        custom_payload_template_slug: Optional[str] = None,
        language: Optional[str] = None,
        mail_ids: OptionalNullable[List[str]] = UNSET,
        custom_payload: Optional[str] = None,
        payload_type: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.V3ExtensionsWebhooksWebhookResponse:
        r"""Update Webhook

        Update organization webhook details.
        Requires `access_token` as a `Bearer {{token}}` in the `Authorization` header with `user-write` scope.

        :param event_webhook_id:
        :param name: Name of the webhook
        :param triggers: A list of triggers for this webhook
        :param urls: A list of URLs to which the webhook payload will be sent
        :param trigger_type: Type of trigger
        :param description: Description of the webhook
        :param header: Headers to be sent with the webhook
        :param filters: Filters to apply to the webhook
        :param max_retry: Maximum number of retries for the webhook
        :param teams: List of team IDs to which this webhook is applicable
        :param is_all_teams_configured: Set to true if the webhook is configured for all teams
        :param custom_payload_template_slug: Slug of the custom payload template
        :param language: Language for the webhook payload
        :param mail_ids: List of email IDs for notification
        :param custom_payload: Custom payload for the webhook
        :param payload_type: Type of payload
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.WebhooksUpdateWebhookRequest(
            event_webhook_id=event_webhook_id,
            v3_extensions_webhooks_webhook=models.V3ExtensionsWebhooksWebhook(
                name=name,
                description=description,
                triggers=utils.get_pydantic_model(
                    triggers, List[models.V3ExtensionsWebhooksWebhookTrigger]
                ),
                urls=utils.get_pydantic_model(
                    urls, List[models.V3ExtensionsWebhooksWebhookURL]
                ),
                header=utils.get_pydantic_model(
                    header, OptionalNullable[models.V3ExtensionsWebhooksWebhookHeader]
                ),
                filters=utils.get_pydantic_model(
                    filters, OptionalNullable[models.V3ExtensionsWebhooksWebhookFilter]
                ),
                max_retry=max_retry,
                teams=teams,
                is_all_teams_configured=is_all_teams_configured,
                custom_payload_template_slug=custom_payload_template_slug,
                language=language,
                mail_ids=mail_ids,
                trigger_type=trigger_type,
                custom_payload=custom_payload,
                payload_type=payload_type,
            ),
        )

        req = self._build_request_async(
            method="PUT",
            path="/v3/extensions/event-webhooks/{eventWebhookID}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.v3_extensions_webhooks_webhook,
                False,
                False,
                "json",
                models.V3ExtensionsWebhooksWebhook,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="Webhooks_updateWebhook",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "402",
                "403",
                "404",
                "409",
                "422",
                "4XX",
                "500",
                "502",
                "503",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.WebhooksUpdateWebhookResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthorizedErrorData, http_res
            )
            raise errors.UnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "402", "application/json"):
            response_data = unmarshal_json_response(
                errors.PaymentRequiredErrorData, http_res
            )
            raise errors.PaymentRequiredError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(errors.ForbiddenErrorData, http_res)
            raise errors.ForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(errors.NotFoundErrorData, http_res)
            raise errors.NotFoundError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(errors.ConflictErrorData, http_res)
            raise errors.ConflictError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res
            )
            raise errors.UnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "502", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadGatewayErrorData, http_res
            )
            raise errors.BadGatewayError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "504", "application/json"):
            response_data = unmarshal_json_response(
                errors.GatewayTimeoutErrorData, http_res
            )
            raise errors.GatewayTimeoutError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)

        raise errors.SDKDefaultError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_auditlogs_actor import V3AuditLogsActor, V3AuditLogsActorTypedDict
from .v3_auditlogs_filters import V3AuditLogsFilters, V3AuditLogsFiltersTypedDict
import pydantic
from squadcast_sdk.types import BaseModel
from typing_extensions import Annotated, TypedDict


class V3AuditLogsAuditLogsExportHistoryResponseTypedDict(TypedDict):
    r"""Response model for audit logs export history"""

    id: str
    name: str
    description: str
    exported_at: str
    requested_by: V3AuditLogsActorTypedDict
    r"""Represents an actor (user) in audit logs"""
    download_link: str
    status: str
    filters: V3AuditLogsFiltersTypedDict
    r"""Represents filters used in audit log queries"""


class V3AuditLogsAuditLogsExportHistoryResponse(BaseModel):
    r"""Response model for audit logs export history"""

    id: str

    name: str

    description: str

    exported_at: Annotated[str, pydantic.Field(alias="exportedAt")]

    requested_by: Annotated[V3AuditLogsActor, pydantic.Field(alias="requestedBy")]
    r"""Represents an actor (user) in audit logs"""

    download_link: Annotated[str, pydantic.Field(alias="downloadLink")]

    status: str

    filters: V3AuditLogsFilters
    r"""Represents filters used in audit log queries"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_users_userresponse import V3UsersUserResponse, V3UsersUserResponseTypedDict
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class UsersAddUserResponseTypedDict(TypedDict):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V3UsersUserResponseTypedDict


class UsersAddUserResponse(BaseModel):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V3UsersUserResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing import Any, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class URLTypedDict(TypedDict):
    url: NotRequired[str]
    method: NotRequired[str]


class URL(BaseModel):
    url: Optional[str] = None

    method: Optional[str] = None


class V3IncidentsIncidentActionsWebhookActionResponseHeaderTypedDict(TypedDict):
    content_type: str


class V3IncidentsIncidentActionsWebhookActionResponseHeader(BaseModel):
    content_type: Annotated[str, pydantic.Field(alias="Content-Type")]


class V3IncidentsIncidentActionsWebhookActionResponseTypedDict(TypedDict):
    r"""Represents the response structure for triggering a webhook manually."""

    id: str
    created_at: str
    updated_at: str
    version: str
    organization_id: str
    author_id: str
    name: str
    slug: str
    description: str
    triggers: List[str]
    urls: List[URLTypedDict]
    teams: List[str]
    is_all_teams_configured: bool
    custom_payload_template_slug: str
    header: V3IncidentsIncidentActionsWebhookActionResponseHeaderTypedDict
    filters: Any
    trigger_type: str
    language: str
    max_retry: int
    mail_ids: List[str]
    payload_type: str
    custom_payload: str


class V3IncidentsIncidentActionsWebhookActionResponse(BaseModel):
    r"""Represents the response structure for triggering a webhook manually."""

    id: str

    created_at: str

    updated_at: str

    version: str

    organization_id: str

    author_id: str

    name: str

    slug: str

    description: str

    triggers: List[str]

    urls: List[URL]

    teams: List[str]

    is_all_teams_configured: bool

    custom_payload_template_slug: str

    header: V3IncidentsIncidentActionsWebhookActionResponseHeader

    filters: Any

    trigger_type: str

    language: str

    max_retry: int

    mail_ids: List[str]

    payload_type: str

    custom_payload: str
